@@ -83,7 +83,7 @@ class CommandExecutor():
             self.child = pexpect.spawn(command_data[0], command_data[1:],
                                        logfile=open(self.logfile, 'w'),
                                        env=self.env, cwd=self.cwd, timeout=None,
-                                       encoding="UTF-8")
+                                       encoding="UTF-8", codec_errors='ignore')
         return self.child
 
     def close(self):
