@@ -1823,9 +1823,11 @@ class Update(MethodsInterface):
                     pass
         return True
 
-    def update_set_current_level(self):
+    def update_increment_current_level(self):
         current_level = int(self.clVars.Get('cl_update_level'))
         self.clVars.Write('cl_update_level', 
                 str(current_level + 1), location="system")
         self.clVars.Set("update.cl_update_use_migration_host",
-                Variable.Off)
\ No newline at end of file
+                Variable.Off)
+        self.delete_binhost()
+        return True
\ No newline at end of file
