@@ -452,7 +452,7 @@ class ClUpdateAction(Action):
          },
         #  #TODO 
          {'name': 'update:set_current_level',
-         'method': 'Update.update_set_current_level()',
+         'method': 'Update.update_increment_current_level()',
          'depend': Tasks.success(), 
          'condition': lambda Get: Get('cl_update_sync_only_set') == 'off' and
                 Get('update.cl_update_use_migration_host') == 'on'
